package com.hrsk.cloud.op.adapter.common;

import com.hrsk.cloud.op.domain.common.ErrorCodeEnum;
import com.hrsk.pangu.dto.Response;
import com.hrsk.pangu.tool.exception.BizException;
import com.hrsk.pangu.tool.exception.SysException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import javax.servlet.http.HttpServletRequest;

/**
 * @author: bianlanzhou
 * @create: 2024-10-22 09:37
 * @description: 全局异常处理
 **/
@Slf4j
@RestControllerAdvice
public class GlobalExceptionHandler {

    /**
     * 业务异常
     * @param e 异常
     * @param request 请求
     * @return 响应
     */
    @ExceptionHandler(BizException.class)
    public Response handleBizException(BizException e, HttpServletRequest request) {
        String requestURI = request.getRequestURI();
        log.error("请求地址'{}',发生业务异常.", requestURI, e);
        return Response.buildFailure(e.getErrCode(), e.getMessage());
    }

    /**
     * 系统异常
     * @param e 异常
     * @param request 请求
     * @return 响应
     */
    @ExceptionHandler(SysException.class)
    public Response handleSysException(SysException e, HttpServletRequest request) {
        String requestURI = request.getRequestURI();
        log.error("请求地址'{}',发生系统异常.", requestURI, e);
        return Response.buildFailure(e.getErrCode(), e.getMessage());
    }
    /**
     * 系统异常
     * @param e 异常
     * @param request 请求
     * @return 响应
     */
    @ExceptionHandler(Exception.class)
    public Response handleException(Exception e, HttpServletRequest request) {
        String requestURI = request.getRequestURI();
        log.error("请求地址'{}',发生系统未定义异常.", requestURI, e);
        return Response.buildFailure(ErrorCodeEnum.FAIL.getCode(), ErrorCodeEnum.FAIL.getMessage());
    }
}
