package com.hrsk.cloud.op.adapter.common.security;

import com.hrsk.cloud.op.client.dto.CurrentLoginUserDTO;
import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.SysUserDO;
import org.springframework.beans.BeanUtils;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.util.Collection;
import java.util.Set;

/**
 * @author: bianlanzhou
 * @create: 2024-10-14 15:18
 * @description: 当前登录用户
 **/
public class CurrentLoginUser implements UserDetails {

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 部门ID
     */
    private Long deptId;

    /**
     * 权限列表
     */
    private Set<String> permissions;

    /**
     * token
     */
    private String token;

    /**
     * 过期时间
     */
    private Long expireTime;

    /**
     * 登录时间
     */
    private Long loginTime;

    /**
     * 登录IP地址
     */
    private String ipaddr;

    /**
     * 登录地点
     */
    private String loginLocation;

    /**
     * 浏览器类型
     */
    private String browser;

    /**
     * 操作系统
     */
    private String os;

    /**
     * otp密钥
     */
    private String otpSecret;
    /**
     * 是否完成双因子验证
     */
    private boolean finishTfa = false;

    /**
     * 系统用户信息
     */
    private SysUserDO user;

    /**
     * 构造函数
     * @param user 系统用户
     * @param permissions 权限
     */
    public CurrentLoginUser(SysUserDO user,Set<String> permissions) {
        this.userId = user.getId();
        this.deptId = user.getDeptId();
        this.otpSecret = user.getOtpSecret();
        this.permissions = permissions;
        this.user = user;
    }

    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        return null;
    }

    @Override
    public String getPassword() {
        return user.getPassword();
    }

    @Override
    public String getUsername() {
        return user.getUsername();
    }

    @Override
    public boolean isAccountNonExpired() {
        return true;
    }

    @Override
    public boolean isAccountNonLocked() {
        return true;
    }

    @Override
    public boolean isCredentialsNonExpired() {
        return true;
    }

    @Override
    public boolean isEnabled() {
        return true;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public Long getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Long expireTime) {
        this.expireTime = expireTime;
    }

    public Long getLoginTime() {
        return loginTime;
    }

    public void setLoginTime(Long loginTime) {
        this.loginTime = loginTime;
    }

    public String getIpaddr() {
        return ipaddr;
    }

    public void setIpaddr(String ipaddr) {
        this.ipaddr = ipaddr;
    }

    public String getLoginLocation() {
        return loginLocation;
    }

    public void setLoginLocation(String loginLocation) {
        this.loginLocation = loginLocation;
    }

    public String getBrowser() {
        return browser;
    }

    public void setBrowser(String browser) {
        this.browser = browser;
    }

    public String getOs() {
        return os;
    }

    public void setOs(String os) {
        this.os = os;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getDeptId() {
        return deptId;
    }

    public void setDeptId(Long deptId) {
        this.deptId = deptId;
    }

    public Set<String> getPermissions() {
        return permissions;
    }

    public void setPermissions(Set<String> permissions) {
        this.permissions = permissions;
    }

    public SysUserDO getUser() {
        return user;
    }

    public void setUser(SysUserDO user) {
        this.user = user;
    }

    public boolean isFinishTfa() {
        return finishTfa;
    }

    public void setFinishTfa(boolean finishTfa) {
        this.finishTfa = finishTfa;
    }

    public String getOtpSecret() {
        return otpSecret;
    }

    public void setOtpSecret(String otpSecret) {
        this.otpSecret = otpSecret;
    }

    /**
     * 转换DTO
     * @return DTO
     */
    public CurrentLoginUserDTO to(){
        CurrentLoginUserDTO dto = new CurrentLoginUserDTO();
        BeanUtils.copyProperties(this.user,dto);
        dto.setPermissions(permissions);
        dto.setLoginIp(ipaddr);
        return dto;
    }

    /**
     * 转换操作者
     * @return 操作者
     */
    public Operator toOperator(){
        return new Operator(getUserId(),getUsername());
    }
}
