package com.hrsk.cloud.op.adapter.controller.egress;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.hrsk.cloud.op.adapter.common.security.HttpSecurityHelper;
import com.hrsk.cloud.op.client.api.EgressApiService;
import com.hrsk.cloud.op.client.dto.EgressApiDTO;
import com.hrsk.cloud.op.client.dto.EgressApiLoanDTO;
import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.client.dto.command.EgressApiUpsertCmd;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanQry;
import com.hrsk.cloud.op.client.dto.command.EgressApiQry;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanCrtCmd;
import com.hrsk.pangu.dto.AntDMultiResponse;
import com.hrsk.pangu.dto.AntDPageResponse;
import com.hrsk.pangu.dto.AntDSingleResponse;
import com.hrsk.pangu.dto.MultiResponse;
import com.hrsk.pangu.dto.PageResponse;
import com.hrsk.pangu.dto.Response;
import com.hrsk.pangu.dto.SingleResponse;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * @author: bianlanzhou
 * @create: 2024-10-21 14:39
 * @description: 接出API控制器
 **/
@RestController()
@RequestMapping("/egress/api")
public class EgressApiController {
    @Resource
    private EgressApiService egressApiService;

    @Resource
    private HttpSecurityHelper httpSecurityHelper;
    /**
     * 分页查询
     * @return
     */
    @GetMapping("/page")
    public AntDPageResponse<EgressApiDTO> page(EgressApiQry egressApiQry){
        PageResponse<EgressApiDTO> response = egressApiService.page(egressApiQry);
        return AntDPageResponse.of(response);
    }

    /**
     * 创建/更新API
     * @param egressApiUpsertCmd
     * @param request
     * @return
     */
    @PutMapping("/upsert")
    public AntDSingleResponse<Long> upsert(@RequestBody EgressApiUpsertCmd egressApiUpsertCmd, HttpServletRequest request){
        Operator operator = httpSecurityHelper.getCurrentLoginUser(request).toOperator();
        SingleResponse response = egressApiService.upsert(egressApiUpsertCmd,operator);
        return AntDSingleResponse.of(response);
    }


    /**
     * 列表查询
     * @return
     */
    @GetMapping("/list")
    public AntDMultiResponse<EgressApiDTO> list(EgressApiQry egressApiQry){
        MultiResponse<EgressApiDTO> response = egressApiService.list(egressApiQry);
        return AntDMultiResponse.of(response);
    }

    /**
     * 助贷API对接
     * @param egressApiLoanCrtCmd 助贷
     * @return
     */
    @PutMapping("/loan/integration")
    public Response loanApiIntegration(@RequestBody EgressApiLoanCrtCmd egressApiLoanCrtCmd, HttpServletRequest request){
        Operator operator = httpSecurityHelper.getCurrentLoginUser(request).toOperator();
        return egressApiService.createLoanApi(egressApiLoanCrtCmd,operator);
    }

    @GetMapping("/loan")
    public SingleResponse<EgressApiLoanDTO> queryLoan(Long apiId){
        EgressApiLoanQry qry = new EgressApiLoanQry();
        qry.setApiId(apiId);
        MultiResponse<EgressApiLoanDTO> multiResponse = egressApiService.queryLoan(qry);
        if(CollectionUtils.isNotEmpty(multiResponse.getData())){
            return SingleResponse.of(multiResponse.getData().get(0));
        }
        return SingleResponse.buildSuccess();
    }

    @DeleteMapping()
    public Response delete(Long id){
        return egressApiService.delete(id);
    }
}
