package com.hrsk.cloud.op.app.egress;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.hrsk.cloud.op.app.egress.executor.EgressApiDelExe;
import com.hrsk.cloud.op.app.egress.executor.EgressApiUpsertExe;
import com.hrsk.cloud.op.app.egress.executor.EgressApiLoanCrtExe;
import com.hrsk.cloud.op.app.egress.executor.EgressApiLoanQryExe;
import com.hrsk.cloud.op.app.egress.executor.EgressApiQryExe;
import com.hrsk.cloud.op.client.api.EgressApiService;
import com.hrsk.cloud.op.client.dto.EgressApiDTO;
import com.hrsk.cloud.op.client.dto.EgressApiLoanDTO;
import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.client.dto.command.EgressApiUpsertCmd;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanCrtCmd;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanQry;
import com.hrsk.cloud.op.client.dto.command.EgressApiQry;
import com.hrsk.pangu.dto.MultiResponse;
import com.hrsk.pangu.dto.PageResponse;
import com.hrsk.pangu.dto.Response;
import com.hrsk.pangu.dto.SingleResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-10-21 14:46
 * @description: 接出API服务实现类
 **/
@Slf4j
@Service
public class EgressApiServiceImpl implements EgressApiService {
    @Resource
    private EgressApiQryExe egressApiQryExe;

    @Resource
    private EgressApiUpsertExe egressApiUpsertExe;

    @Resource
    private EgressApiLoanCrtExe egressApiLoanCrtExe;

    @Resource
    private EgressApiLoanQryExe egressApiLoanQryExe;

    @Resource
    private EgressApiDelExe egressApiDelExe;

    @Override
    public PageResponse<EgressApiDTO> page(EgressApiQry egressApiQry) {
        Page<EgressApiDTO> page = PageHelper.startPage(egressApiQry.getCurrent(), egressApiQry.getPageSize());
        return PageResponse.of(egressApiQryExe.execute(egressApiQry),page.getTotal(),page.getPageSize(),page.getPageNum());
    }

    @Override
    public SingleResponse<Long> upsert(EgressApiUpsertCmd egressApiUpsertCmd, Operator operator) {
        Long id = egressApiUpsertExe.execute(egressApiUpsertCmd,operator);
        return SingleResponse.of(id);
    }

    @Override
    public MultiResponse<EgressApiDTO> list(EgressApiQry egressApiQry) {
        List<EgressApiDTO> list = egressApiQryExe.execute(egressApiQry);
        return MultiResponse.of(list);
    }

    @Override
    public Response createLoanApi(EgressApiLoanCrtCmd egressApiLoanCrtCmd, Operator operator) {
        egressApiLoanCrtExe.execute(egressApiLoanCrtCmd,operator);
        return Response.buildSuccess();
    }

    @Override
    public MultiResponse<EgressApiLoanDTO> queryLoan(EgressApiLoanQry egressApiLoanQry) {
        return MultiResponse.of(egressApiLoanQryExe.execute(egressApiLoanQry));
    }

    @Override
    public Response delete(Long id) {
        egressApiDelExe.execute(id);
        return Response.buildSuccess();
    }
}
