package com.hrsk.cloud.op.app.egress.executor;

import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.client.dto.command.EgressApiChannelUpsertCmd;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanCrtCmd;
import com.hrsk.cloud.op.domain.common.EgressApiErrorCodeEnum;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.EgressApiDO;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.EgressApiLoanDO;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.mapper.EgressApiLoanMapper;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.mapper.EgressApiMapper;
import com.hrsk.pangu.tool.exception.BizException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.transaction.support.TransactionTemplate;

import javax.annotation.Resource;

/**
 * @author: bianlanzhou
 * @create: 2024-10-27 19:26
 * @description: 助贷API创建EXE
 **/
@Slf4j
@Component
public class EgressApiLoanCrtExe {
    private static final String LOAN_CHANNEL_NAME_CHECK_FORMAT = "%s-撞库";
    private static final String LOAN_CHANNEL_NAME_APPLY_FORMAT = "%s-注册";
    @Resource
    private EgressApiChannelCrtExe egressApiChannelCrtExe;
    @Resource
    private EgressApiMapper egressApiMapper;
    @Resource
    private EgressApiLoanMapper egressApiLoanMapper;
    @Resource
    private TransactionTemplate transactionTemplate;
    /**
     * 执行
     * @param egressApiLoanCrtCmd CMD
     * @param operator 操作人
     */
    public void execute(EgressApiLoanCrtCmd egressApiLoanCrtCmd, Operator operator){
        EgressApiDO egressApiDO = egressApiMapper.selectById(egressApiLoanCrtCmd.getApiId());
        if(egressApiDO == null){
            throw new BizException(EgressApiErrorCodeEnum.API_NOT_EXIST.getCode(),EgressApiErrorCodeEnum.API_NOT_EXIST.getMessage());
        }
        transactionTemplate.execute(status -> {
            try {
                createApiChannels(egressApiDO.getApiName(),egressApiLoanCrtCmd,operator);
                createEgressApiLoan(egressApiLoanCrtCmd,operator);
            }catch (Exception ex){
                log.error("创建失败!",ex);
                status.setRollbackOnly();
                throw new BizException(EgressApiErrorCodeEnum.API_CHANNEL_CRT_FAIL.getCode(),EgressApiErrorCodeEnum.API_CHANNEL_CRT_FAIL.getMessage(),ex);
            }
            return null;
        });
    }

    /**
     * 创建CHANNEL
     * @param egressApiLoanCrtCmd cmd
     * @param operator 操作人
     */
    private void createApiChannels(String apiName,EgressApiLoanCrtCmd egressApiLoanCrtCmd, Operator operator){
        //checkinto
        EgressApiChannelUpsertCmd checkinto = egressApiLoanCrtCmd.getCheckinto();
        checkinto.setChannelCode("checkinto");
        checkinto.setChannelName(String.format(LOAN_CHANNEL_NAME_CHECK_FORMAT,apiName));
        egressApiChannelCrtExe.execute(checkinto,operator);
        //apply
        EgressApiChannelUpsertCmd apply = egressApiLoanCrtCmd.getApply();
        apply.setChannelName(String.format(LOAN_CHANNEL_NAME_APPLY_FORMAT,apiName));
        apply.setChannelCode("apply");
        egressApiChannelCrtExe.execute(apply,operator);
    }

    /**
     * 创建API LOAN
     * @param egressApiLoanCrtCmd CMD
     * @param operator 操作人
     */
    private void createEgressApiLoan(EgressApiLoanCrtCmd egressApiLoanCrtCmd, Operator operator){
        EgressApiLoanDO egressApiLoan = EgressApiLoanDO.from(egressApiLoanCrtCmd.getApiLoanInfo(),operator);
        egressApiLoan.setApiId(egressApiLoanCrtCmd.getApiId());
        egressApiLoanMapper.insert(egressApiLoan);
    }
}
