package com.hrsk.cloud.op.app.egress.executor;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.client.dto.command.EgressApiUpsertCmd;
import com.hrsk.cloud.op.domain.common.EgressApiErrorCodeEnum;
import com.hrsk.cloud.op.domain.egress.EgressApiStatusEnum;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.EgressApiDO;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.SysUserDO;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.mapper.EgressApiMapper;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.mapper.SysUserMapper;
import com.hrsk.pangu.tool.exception.BizException;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-10-22 09:45
 * @description: 接出API创建EXE
 **/
@Component
public class EgressApiUpsertExe {
    @Resource
    private EgressApiMapper egressApiMapper;
    @Resource
    private SysUserMapper sysUserMapper;

    /**
     * 处理
     * @param egressApiUpsertCmd CMD
     * @param operator 操作人
     * @return ID
     */
    public Long execute(EgressApiUpsertCmd egressApiUpsertCmd, Operator operator){
        SysUserDO techOwner = sysUserMapper.selectById(egressApiUpsertCmd.getTechOwnerUserid());
        if(techOwner == null){
            throw new BizException(EgressApiErrorCodeEnum.TECH_OWNER_NOT_EXIST.getCode(),EgressApiErrorCodeEnum.TECH_OWNER_NOT_EXIST.getMessage());
        }
        EgressApiDO egressApiDO = EgressApiDO.from(egressApiUpsertCmd,operator);
        egressApiDO.setStatus(EgressApiStatusEnum.DRAFT.getCode());
        egressApiDO.setTechOwnerUsername(techOwner.getUsername());
        if(egressApiUpsertCmd.getId()!=null && egressApiUpsertCmd.getId()>0){
            egressApiMapper.updateById(egressApiDO);
        }else{
            check(egressApiUpsertCmd);
            egressApiMapper.insert(egressApiDO);
        }
        return egressApiDO.getId();
    }

    /**
     * 校验
     * @param egressApiUpsertCmd cmd
     */
    private void check(EgressApiUpsertCmd egressApiUpsertCmd){
        checkByName(egressApiUpsertCmd);
        checkByCode(egressApiUpsertCmd);
    }

    /**
     * 校验名称
     * @param egressApiUpsertCmd cmd
     */
    private void checkByName(EgressApiUpsertCmd egressApiUpsertCmd){
        EgressApiDO byName = new EgressApiDO();
        byName.setApiName(egressApiUpsertCmd.getApiName());
        QueryWrapper<EgressApiDO> queryWrapper = Wrappers
                .query(byName);
        List<EgressApiDO> egressApis = egressApiMapper.selectList(queryWrapper);
        if(egressApis.size()>0){
            throw new BizException(EgressApiErrorCodeEnum.API_NAME_IS_DUPLICATE.getCode(),EgressApiErrorCodeEnum.API_NAME_IS_DUPLICATE.getMessage());
        }
    }


    /**
     * 校验编码
     * @param egressApiUpsertCmd cmd
     */
    private void checkByCode(EgressApiUpsertCmd egressApiUpsertCmd){
        EgressApiDO byCode = new EgressApiDO();
        byCode.setApiCode(egressApiUpsertCmd.getApiCode());
        QueryWrapper<EgressApiDO> queryWrapper = Wrappers
                .query(byCode);
        List<EgressApiDO> egressApis = egressApiMapper.selectList(queryWrapper);
        if(egressApis.size()>0){
            throw new BizException(EgressApiErrorCodeEnum.API_CODE_IS_DUPLICATE.getCode(),EgressApiErrorCodeEnum.API_CODE_IS_DUPLICATE.getMessage());
        }
    }
}
