package com.hrsk.cloud.op.app.system;

import com.hrsk.cloud.op.client.api.SysMenuService;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.SysRoleDO;
import com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity.SysUserDO;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author: bianlanzhou
 * @create: 2024-10-16 20:03
 * @description: 系统权限实现类
 **/
@Service
public class SysPermissionSerivce {
    @Resource
    private SysMenuService sysMenuService;
    /**
     * 获取菜单权限
     * @param sysUser 系统用户
     * @return 权限集合
     */
    public Set<String> getMenuPermission(SysUserDO sysUser) {
        Set<String> perms = new HashSet<String>();
        // 管理员拥有所有权限
        if (sysUser.isAdmin()) {
            perms.add("*:*:*");
        } else {
            List<SysRoleDO> roles = sysUser.getRoles();
            if (!CollectionUtils.isEmpty(roles)) {
                // 多角色设置permissions属性，以便数据权限匹配权限
                for (SysRoleDO role : roles) {
                    Set<String> rolePerms = sysMenuService.selectMenuPermsByRoleId(role.getId());
                    perms.addAll(rolePerms);
                }
            } else {
                perms.addAll(sysMenuService.selectMenuPermsByUserId(sysUser.getId()));
            }
        }
        return perms;
    }
}
