package com.hrsk.cloud.op.app.system.executor;

import com.google.code.kaptcha.Producer;
import com.hrsk.cloud.op.client.dto.CaptchaDTO;
import com.hrsk.cloud.op.infrastructure.common.Base64;
import com.hrsk.cloud.op.infrastructure.common.CaptchaTypeEnum;
import com.hrsk.cloud.op.infrastructure.repository.database.redis.RedisCache;
import com.hrsk.cloud.op.infrastructure.repository.database.redis.RedisKeyEnum;
import com.hrsk.pangu.tool.exception.BizException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Component;
import org.springframework.util.FastByteArrayOutputStream;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @author: bianlanzhou
 * @create: 2024-10-11 15:51
 * @description: 验证码创建CMD
 **/
@Slf4j
@Component
public class CaptchaCreateCmdExe {

    /**
     * 验证码超时时间
     */
    private static final Integer CAPTCHA_EXPIRATION = 1;

    /**
     * 验证码超时时间单位
     */
    private static final TimeUnit CAPTCHA_EXPIRATION_UNIT = TimeUnit.MINUTES;

    @Resource(name = "captchaProducer")
    private Producer captchaProducer;

    @Resource
    private RedisCache redisCache;

    /**
     * 执行
     * @param captchaType 验证码类型 ref:com.hrsk.cloud.op.infrastructure.common.CaptchaTypeEnum
     * @return 验证码DTO
     */
    public CaptchaDTO execute(String captchaType){
        CaptchaDTO captchaDto = null;
        if(StringUtils.equals(captchaType,CaptchaTypeEnum.IMAGE.getCode())){
            captchaDto = imageCaptcha();
        }else{
            throw new BizException("不支持的验证码类型!");
        }
        redisCache.setCacheObject(RedisKeyEnum.CAPTCHA.getKey(captchaDto.getUuid()), captchaDto.getCode(), CAPTCHA_EXPIRATION, CAPTCHA_EXPIRATION_UNIT);
        return captchaDto;
    }

    /**
     * 创建图片验证码
     * @return 验证码DTO
     */
    private CaptchaDTO imageCaptcha(){
        String uuid = UUID.randomUUID().toString();
        String capText = captchaProducer.createText();
        String capStr = capText.substring(0, capText.lastIndexOf("@"));
        String code = capText.substring(capText.lastIndexOf("@") + 1);
        BufferedImage image = captchaProducer.createImage(capStr);
        // 转换流信息写出
        FastByteArrayOutputStream os = new FastByteArrayOutputStream();
        try {
            ImageIO.write(image, "jpg", os);
        } catch (IOException e) {
            log.error("创建验证码异常!",e);
        }
        return new CaptchaDTO(uuid, Base64.encode(os.toByteArray()), CaptchaTypeEnum.IMAGE.getCode(),code);
    }
}
