package com.hrsk.cloud.op.client.api;

import com.hrsk.cloud.op.client.dto.EgressApiDTO;
import com.hrsk.cloud.op.client.dto.EgressApiLoanDTO;
import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.client.dto.command.EgressApiUpsertCmd;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanCrtCmd;
import com.hrsk.cloud.op.client.dto.command.EgressApiLoanQry;
import com.hrsk.cloud.op.client.dto.command.EgressApiQry;
import com.hrsk.pangu.dto.MultiResponse;
import com.hrsk.pangu.dto.PageResponse;
import com.hrsk.pangu.dto.Response;
import com.hrsk.pangu.dto.SingleResponse;

/**
 * @author: bianlanzhou
 * @create: 2024-10-21 14:46
 * @description: 接出API服务
 **/
public interface EgressApiService {
    /**
     * 分页查询接出API
     * @param egressApiQry 查询条件
     * @return 分页数据
     */
    PageResponse<EgressApiDTO> page(EgressApiQry egressApiQry);

    /**
     * 创建/更新API
     * @param egressApiUpsertCmd cmd
     * @param operator 操作人
     * @return ID
     */
    SingleResponse<Long> upsert(EgressApiUpsertCmd egressApiUpsertCmd, Operator operator);


    /**
     * 查询接出API列表
     * @param egressApiQry 查询条件
     * @return 分页数据
     */
    MultiResponse<EgressApiDTO> list(EgressApiQry egressApiQry);

    /**
     * 创建助贷API
     * @param egressApiLoanCrtCmd cmd
     * @param operator 操作人
     * @return
     */
    Response createLoanApi(EgressApiLoanCrtCmd egressApiLoanCrtCmd, Operator operator);


    /**
     * 查询API助贷信息
     * @param egressApiLoanQry CMD
     * @return 助贷信息
     */
    MultiResponse<EgressApiLoanDTO> queryLoan(EgressApiLoanQry egressApiLoanQry);

    /**
     * 删除API
     * @param id 主键
     * @return
     */
    Response delete(Long id);
}
