package com.hrsk.cloud.op.infrastructure.client;

import com.alibaba.fastjson2.JSON;
import com.hrsk.cloud.op.client.dto.command.EgressApiChannelUpsertCmd;
import lombok.extern.slf4j.Slf4j;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-10-27 20:48
 * @description: 接出服务客户端
 **/
@Slf4j
@Component
public class EgressServiceClient {

    @Value(value = "${egress.service.url}")
    private String egServiceUrl;
    private final OkHttpClient client = new OkHttpClient();

    public static final MediaType CONTENT_TYPE_JSON = MediaType.parse("application/json; charset=utf-8");

    /**
     * 批量创建API通道
     * @param egressApiChannelUpsertCmds cmds
     */
    public boolean batchCreateApiChannel(List<EgressApiChannelUpsertCmd> egressApiChannelUpsertCmds) throws IOException {
        String requestBody = JSON.toJSONString(egressApiChannelUpsertCmds);
        log.info("开始http请求(post),url:{},payload:{}", egServiceUrl+"/api/egressApiChannel/batchCreate", requestBody);
        RequestBody body = RequestBody.create(requestBody, CONTENT_TYPE_JSON);
        Request request = new Request.Builder()
                .url(egServiceUrl)
                .post(body)
                .build();
        try (Response response = client.newCall(request).execute()) {
            if(response.body() == null){
                return false;
            }
            return JSON.parseObject(response.body().toString(), com.hrsk.pangu.dto.Response.class).isSuccess();
        }
    }
}
