package com.hrsk.cloud.op.infrastructure.repository.database.mysql.entity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.hrsk.cloud.op.client.dto.EgressApiChannelDTO;
import com.hrsk.cloud.op.client.dto.Operator;
import com.hrsk.cloud.op.client.dto.command.EgressApiChannelUpsertCmd;
import com.hrsk.cloud.op.domain.egress.EgressApiStatusEnum;
import lombok.Data;
import org.springframework.beans.BeanUtils;

/**
 * @author: bianlanzhou
 * @create: 2024-10-23 14:25
 * @description: 表 egress_api_channel 数据对象。
 **/
@Data
@TableName("egress_api_channel")
public class EgressApiChannelDO extends BaseDO{

    /**
     * ID
     */
    private Long id;

    /**
     * egress_api的主键
     */
    private Long apiId;

    /**
     * api名称
     */
    @TableField(exist = false)
    private String apiName;

    /**
     * API类型
     */
    @TableField(exist = false)
    private String apiType;

    /**
     * 通道名称
     */
    private String channelName;
    /**
     * 通道编码
     */
    private String channelCode;
    /**
     * 集成方式
     */
    private String integrationMode;

    /**
     * 请求配置
     */
    private String requestConfig;

    /**
     * 响应配置
     */
    private String responseConfig;

    /**
     * 版本
     */
    private String version;

    /**
     * 备注
     */
    private String memo;

    /**
     * 转化
     * @param egressApiChannelUpsertCmd cmd
     * @param version 版本
     * @param operator cmd
     * @return EgressApiChannelDO
     */
    public static EgressApiChannelDO from(EgressApiChannelUpsertCmd egressApiChannelUpsertCmd, String version, Operator operator){
        EgressApiChannelDO egressApiChannel = new EgressApiChannelDO();
        BeanUtils.copyProperties(egressApiChannelUpsertCmd,egressApiChannel);
        egressApiChannel.setRequestConfig(egressApiChannelUpsertCmd.getRequestConfig());
        egressApiChannel.setResponseConfig(egressApiChannelUpsertCmd.getResponseConfig());
        egressApiChannel.setCreateUserid(operator.getId());
        egressApiChannel.setCreateUsername(operator.getUsername());
        egressApiChannel.setModifyUserid(operator.getId());
        egressApiChannel.setModifyUsername(operator.getUsername());
        egressApiChannel.setVersion(version);
        egressApiChannel.setStatus(EgressApiStatusEnum.OK.getCode());
        return egressApiChannel;
    }

    /**
     * 转DTO
     * @return
     */
    public EgressApiChannelDTO toDTO(){
        EgressApiChannelDTO egressApiChannel = new EgressApiChannelDTO();
        BeanUtils.copyProperties(this,egressApiChannel);
        egressApiChannel.setRequestConfig(requestConfig);
        egressApiChannel.setResponseConfig(responseConfig);
        return egressApiChannel;
    }

}
